@@ -1,3 +1,4 @@
+(function($){  //$-safe plugin
 
 var AttachedImagesAdminUploader = new Class({
     Extends: DjangoImageUploader,
@@ -90,4 +91,6 @@ window.addEvent('domready', function(){
         $('gears-uploader').show();
         $('gears-please-install').hide();
     }
-});
\ No newline at end of file
+});
+
+})(document.id); // end $-safe plugin
